# Generated by Django 4.1 on 2022-11-26 10:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0008_auto_20210128_0337'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subscriptionplan',
            options={'ordering': ('sequence',), 'permissions': (('subscriptions', 'Can interact with subscription details'),)},
        ),
        migrations.AddField(
            model_name='subscriptionplan',
            name='sequence',
            field=models.IntegerField(default=0, help_text='order by sequence '),
        ),
        migrations.AddField(
            model_name='usersubscription',
            name='quantity',
            field=models.IntegerField(default=1, help_text='Subscription Quantity'),
        ),
        migrations.AlterField(
            model_name='planlist',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='planlistdetail',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='plantag',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
