# Generated by Django 3.0.5 on 2020-10-17 06:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0004_auto_20200908_1400'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='planlist',
            options={'ordering': ('title',)},
        ),
        migrations.AlterField(
            model_name='subscriptionplan',
            name='features',
            field=models.TextField(blank=True, help_text='list of json allowed features for this plan', null=True),
        ),
    ]
