# Generated by Django 3.0.5 on 2020-10-17 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0005_auto_20201017_0651'),
    ]

    operations = [
        migrations.AddField(
            model_name='usersubscription',
            name='reference',
            field=models.CharField(blank=True, help_text='External System Reference', max_length=100, null=True),
        ),
    ]
