# Generated by Django 3.0.5 on 2020-11-17 12:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0006_usersubscription_reference'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='planlist',
            name='features_ref',
        ),
        migrations.AddField(
            model_name='planlist',
            name='features',
            field=models.TextField(blank=True, help_text='Json dict for allowed features to display for the plan list', null=True),
        ),
    ]
