# Generated by Django 4.1 on 2022-11-27 01:09

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0009_alter_subscriptionplan_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='plancost',
            name='min_subscription_quantity',
            field=models.IntegerField(default=1, help_text='optional minimum subscription qty  user needs to subscribe to use this cost for usage and tiered base subscription', validators=[django.core.validators.MinValueValidator(1)]),
        ),
    ]
